-------------------------------------------------------------------------------
--
-- Decodificador de Escrita
--
-- Este bloco combinacional gera sinais de habilitao de escrita nos
-- registradores do Bloco de Dados.
-- CUIDADO: O sinal hold somente deve ser ativado pelo mundo externo
--		  durante um ciclo de leitura da memria (ce='1', rw='1').
--		  Se isto no for respeitado, funcionamento incorreto do
--		  processador pode ocorrer devido ao tratamento feito neste mdulo.
--
--   FERNANDO GEHM MORAES         03/agosto/2005
--   NEY LAERT VILAR CALAZANS     18/junho/2006
--   CSAR AUGUSTO MISSIO MARCON  10/abril/2008
--
-------------------------------------------------------------------------------
library IEEE;
use IEEE.Std_Logic_1164.all;
use work.PacoteCleopatra.all;

entity DecodificadorEscrita is
	port
	(
		write_reg: in std_logic_vector(3 downto 0);
		hold: in std_logic;
		w_mar: out std_logic;
		w_mdr: out std_logic;
		w_ir: out std_logic;
		w_pc: out std_logic;
		w_ac: out std_logic;
		w_rs: out std_logic;
		w_idx: out std_logic
	);
end DecodificadorEscrita;

architecture DecodificadorEscrita of DecodificadorEscrita is
begin

	--- Cdigos de escrita nos registradores (codificao de escrita):
	--- 0 MAR, 1 MDR, 2 IR, 3 PC, 4 AC, 5 RS, 6 PC/MDR, 8 IDX, DEMAIS -> nenhum reg. alterado

	w_mar <= '1' when hold = '0' and write_reg = "0000" else '0';
	w_mdr <= '1' when hold = '0' and (write_reg = "0001" or write_reg="0110") else '0';
	w_ir  <= '1' when hold = '0' and write_reg = "0010" else '0';
	w_pc  <= '1' when hold = '0' and (write_reg = "0011" or write_reg="0110") else '0';
	w_ac  <= '1' when hold = '0' and write_reg = "0100" else '0';
	w_rs  <= '1' when hold = '0' and write_reg = "0101" else '0';
	w_idx <= '1' when hold = '0' and write_reg = "1000" else '0';

end DecodificadorEscrita;